@@ -1,15 +1,15 @@
 #' CanvasXpress Visualization Package
 #'
-#' A package to assist in creating visualizations in CanvasXpress in R. 
-#' 
+#' A package to assist in creating visualizations in CanvasXpress in R.
+#'
 #' CanvasXpress is a standalone JavaScript library for reproducible research
-#' with complete tracking of data and end-user modifications stored in a single 
+#' with complete tracking of data and end-user modifications stored in a single
 #' PNG image that can be played back for an extensive set of visualizations.
 #'
 #'
 #' @section More Information:
-#' \url{http://canvasxpress.org}  
-#' 
+#' \url{http://canvasxpress.org}
+#'
 #' \code{browseVignettes(package = "canvasXpress")}
 #'
 #' @docType package
@@ -19,17 +19,17 @@
 
 #' canvasXpress
 #'
-#' Custom HTML widget creation function based on widget YAML and JavaScript for 
+#' Custom HTML widget creation function based on widget YAML and JavaScript for
 #' use in any html-compatible context
-#'  
-#' 
+#'
+#'
 #' @param data data.frame-, matrix-, or list- classed data object
 #' @param smpAnnot additional data that applies to samples (columns)
 #' @param varAnnot additional data that applies to variables (rows)
 #' @param graphType type of graph to be plotted - default = "Scatter2D"
 #' @param events user-defined events (e.g. mousemove, mouseout, click and dblclick)
 #' @param afterRender event triggered after rendering
-#' @param pretty print tagged code (json/html) nicely - default = FALSE
+#' @param pretty print tagged code (JSON/HTML) nicely - default = FALSE
 #' @param digits display digits - default = 4
 #' @param width plot width (valid CSS units) - default = 600px
 #' @param height plot height (valid CSS units) - default = 400px
@@ -43,31 +43,32 @@ canvasXpress <- function(data = NULL,
                          smpAnnot = NULL,
                          varAnnot = NULL,
                          #config items
-                         graphType = "Scatter2D", 
+                         graphType = "Scatter2D",
                          # straight-through
-                         events = NULL, 
+                         events = NULL,
                          afterRender=NULL,
                          #htmlwidgets options
                          pretty = FALSE,
                          digits = 4,
-                         width  = 600, 
+                         width  = 600,
                          height = 400,
                          destroy = FALSE,
                          ... ) {
-    
+
     if (destroy) {
         return(htmlwidgets::createWidget("canvasXpress", list()))
     }
-    
+
     config <- list(graphType = graphType, isR = TRUE, ...)
     assertDataCorrectness(data, graphType, config)
-    
+
     x             <- NULL
     y             <- NULL
     z             <- NULL
     dataframe     <- "columns"
-    precalc.names <- c("iqr1", "qtl1", "median", "qtl3", "iqr3", "outliers")
-        
+    precalc.box   <- c("iqr1", "qtl1", "median", "qtl3", "iqr3", "outliers")
+    precalc.bar   <- c("mean", "stdev")
+
 	# Implement data in URL
 	if (is.character(data)) {
 		if (httr::http_error(data)) {
@@ -75,8 +76,8 @@ canvasXpress <- function(data = NULL,
 		}
 		# CanvasXpress Object
 		cx_object <- list(data        = data,
-				          config      = config, 
-				          events      = events, 
+				          config      = config,
+				          events      = events,
 				          afterRender = afterRender)
 	}
 	else if (graphType == "Venn") {
@@ -98,23 +99,23 @@ canvasXpress <- function(data = NULL,
             }
         }
         legend <- config$vennLegend
-       
+
         # Config - remove venn items
         config <- config[!(names(config) %in% c("vennData", "vennLegend"))]
-        
+
         # CanvasXpress Object
         cx_object <- list(data        = list(venn = list(data = vdata, legend = legend)),
-                          config      = config, 
-                          events      = events, 
+                          config      = config,
+                          events      = events,
                           afterRender = afterRender)
     }
-    else if (graphType == "Map" && 
+    else if (graphType == "Map" &&
              (is.null(data) || (inherits(data, "logical") && data == FALSE))) {
 
         # CanvasXpress Object
-        cx_object <- list(data        = FALSE, 
-                          config      = config, 
-                          events      = events, 
+        cx_object <- list(data        = FALSE,
+                          config      = config,
+                          events      = events,
                           afterRender = afterRender)
     }
     else if (graphType == "Network") {
@@ -131,20 +132,20 @@ canvasXpress <- function(data = NULL,
             ndata <- data$nodeData
             edata <- data$edgeData
         }
-        
+
         # CanvasXpress Object
         cx_object <- list(data        = list(nodes = ndata, edges = edata),
-                          config      = config, 
-                          events      = events, 
+                          config      = config,
+                          events      = events,
                           afterRender = afterRender)
     }
     else if (graphType == "Genome") {
         stop("The Genome graphType is not yet implemented")
     }
     else if (graphType == "Boxplot" &&
-             ((length(intersect(names(data), precalc.names[1:5])) == 5) || 
-              (length(intersect(rownames(data), precalc.names[1:5])) == 5))) {
-        
+             ((length(intersect(names(data), precalc.box[1:5])) == 5) ||
+              (length(intersect(rownames(data), precalc.box[1:5])) == 5))) {
+
         if (inherits(data, "list")) {
             data.names <- names(data)
             iqr1       <- as.matrix(t(data[["iqr1"]]));   dimnames(iqr1)   <- NULL
@@ -152,18 +153,18 @@ canvasXpress <- function(data = NULL,
             median     <- as.matrix(t(data[["median"]])); dimnames(median) <- NULL
             qtl1       <- as.matrix(t(data[["qtl1"]]));   dimnames(qtl1)   <- NULL
             qtl3       <- as.matrix(t(data[["qtl3"]]));   dimnames(qtl3)   <- NULL
-            
+
             if (!is.null(smpAnnot)) {
                 if (inherits(smpAnnot, "character")) {
                     smps <- smpAnnot
                 }
                 else {
-                    smps <- names(smpAnnot)
+                    smps <- rownames(smpAnnot)
                 }
             } else {
                 smps <- make.names(1:length(data[["iqr1"]]))
             }
-            
+
             y <- list(smps   = as.list(smps),
                       vars   = as.list("precalculated BoxPlot"),
                       iqr1   = iqr1,
@@ -178,9 +179,6 @@ canvasXpress <- function(data = NULL,
                 out.new <- sapply(out.new, as.list)
                 y$out <- list(out.new)
             }
-            for (other in setdiff(data.names, precalc.names)) {
-                y[[other]] <- data[other]
-            }
         }
         else {
             data.names <- rownames(data)
@@ -189,7 +187,7 @@ canvasXpress <- function(data = NULL,
             median <- as.matrix(data["median",]); dimnames(median) <- NULL
             qtl1   <- as.matrix(data["qtl1",]);   dimnames(qtl1)   <- NULL
             qtl3   <- as.matrix(data["qtl3",]);   dimnames(qtl3)   <- NULL
-            
+
             y <- list(smps   = as.list(assignCanvasXpressColnames(data)),
                       vars   = as.list("precalculated BoxPlot"),
                       iqr1   = iqr1,
@@ -206,20 +204,17 @@ canvasXpress <- function(data = NULL,
                     y$out <- list(out.new)
                 }
             }
-            for (other in setdiff(data.names, precalc.names)) {
-                y[[other]] <- data[other,]
-            }
         }
 
         if (!is.null(smpAnnot)) {
             if (!inherits(data, "list")) {
                 test <- as.list(assignCanvasXpressRownames(smpAnnot))
-                
+
                 if (!identical(test, y$smps)) {
                     smpAnnot <- t(smpAnnot)
                     test <- as.list(assignCanvasXpressRownames(smpAnnot))
                 }
-                
+
                 if (!identical(test, y$smps)) {
                     stop("Row names in smpAnnot are different from column names in data")
                 }
@@ -228,13 +223,75 @@ canvasXpress <- function(data = NULL,
                 x <- lapply(convertRowsToList(t(smpAnnot)), function(d) if (length(d) > 1) d else list(d))
             }
         }
-        
+
         # NOTE: z should always be null with a boxplot chart
 
         # CanvasXpress Object
-        cx_object <- list(data        = list(y = y, x = x, z = z), 
-                          config      = config, 
-                          events      = events, 
+        cx_object <- list(data        = list(y = y, x = x, z = z),
+                          config      = config,
+                          events      = events,
+                          afterRender = afterRender)
+    }
+    else if (graphType == "Bar" &&
+             ((length(intersect(names(data), precalc.bar[1:2])) == 2) ||
+              (length(intersect(rownames(data), precalc.bar[1:2])) == 2))) {
+
+        if (inherits(data, "list")) {
+            data.names <- names(data)
+            mean       <- as.matrix(t(data[["mean"]]));   dimnames(mean)   <- NULL
+            stdev      <- as.matrix(t(data[["stdev"]]));  dimnames(stdev)  <- NULL
+
+            if (!is.null(smpAnnot)) {
+                if (inherits(smpAnnot, "character")) {
+                    smps <- smpAnnot
+                }
+                else {
+                    smps <- rownames(smpAnnot)
+                }
+            } else {
+                smps <- make.names(1:length(data[["mean"]]))
+            }
+
+            y <- list(smps   = as.list(smps),
+                      vars   = as.list("precalculated BarChart"),
+                      mean   = mean,
+                      stdev  = stdev)
+        }
+        else {
+            data.names <- rownames(data)
+            mean   <- as.matrix(data["mean",]);   dimnames(mean)   <- NULL
+            stdev  <- as.matrix(data["stdev",]);  dimnames(stdev)  <- NULL
+
+            y <- list(smps   = as.list(assignCanvasXpressColnames(data)),
+                      vars   = as.list("precalculated BarChart"),
+                      mean   = mean,
+                      stdev  = stdev)
+        }
+
+        if (!is.null(smpAnnot)) {
+            if (!inherits(data, "list")) {
+                test <- as.list(assignCanvasXpressRownames(smpAnnot))
+
+                if (!identical(test, y$smps)) {
+                    smpAnnot <- t(smpAnnot)
+                    test <- as.list(assignCanvasXpressRownames(smpAnnot))
+                }
+
+                if (!identical(test, y$smps)) {
+                    stop("Row names in smpAnnot are different from column names in data")
+                }
+            }
+            if (!inherits(smpAnnot, "character")) {
+                x <- lapply(convertRowsToList(t(smpAnnot)), function(d) if (length(d) > 1) d else list(d))
+            }
+        }
+
+        z <- setup_z(y$vars, varAnnot)
+
+        # CanvasXpress Object
+        cx_object <- list(data        = list(y = y, x = x, z = z),
+                          config      = config,
+                          events      = events,
                           afterRender = afterRender)
     }
     # standard graph
@@ -244,18 +301,18 @@ canvasXpress <- function(data = NULL,
         z <- setup_z(y$vars, varAnnot)
 
         # CanvasXpress Object
-        cx_object <- list(data        = list(y = y, x = x, z = z), 
-                          config      = config, 
-                          events      = events, 
+        cx_object <- list(data        = list(y = y, x = x, z = z),
+                          config      = config,
+                          events      = events,
                           afterRender = afterRender)
     } #standard graph
 
-    options(htmlwidgets.TOJSON_ARGS = list(dataframe = dataframe, 
-                                           pretty    = pretty, 
-                                           digits    = digits))
+    attr(cx_object, 'TOJSON_ARGS') <- list(dataframe = dataframe,
+                                           pretty    = pretty,
+                                           digits    = digits)
 
-    htmlwidgets::createWidget(name = "canvasXpress", 
-                              cx_object, 
+    htmlwidgets::createWidget(name = "canvasXpress",
+                              cx_object,
                               width  = width,
                               height = height,
                               package = "canvasXpress")
@@ -265,9 +322,9 @@ canvasXpress <- function(data = NULL,
 
 #' canvasXpressOutput
 #'
-#' Output creation function for canvasXpressOutput in Shiny applications and 
+#' Output creation function for canvasXpressOutput in Shiny applications and
 #' interactive Rmd documents
-#'  
+#'
 #' @param outputId shiny unique ID
 #' @param width width of the element - default = 100\%
 #' @param height height of the element - default = 400px
@@ -276,10 +333,10 @@ canvasXpress <- function(data = NULL,
 #'
 #' @seealso \link[canvasXpress]{renderCanvasXpress}
 #' @seealso \link[canvasXpress]{cxShinyExample}
-#' 
+#'
 #' @export
 canvasXpressOutput <- function(outputId, width = "100%", height = "400px") {
-    htmlwidgets::shinyWidgetOutput(outputId, "canvasXpress", 
+    htmlwidgets::shinyWidgetOutput(outputId, "canvasXpress",
                                    width, height,  package = "canvasXpress")
 }
 
@@ -287,9 +344,9 @@ canvasXpressOutput <- function(outputId, width = "100%", height = "400px") {
 
 #' renderCanvasXpress
 #'
-#' Render function for canvasXpressOutput in Shiny applications and 
+#' Render function for canvasXpressOutput in Shiny applications and
 #' interactive Rmd documents
-#'  
+#'
 #' @param expr expression used to render the canvasXpressOutput
 #' @param env environment to use - default = parent.frame()
 #' @param quoted whether the expression is quoted - default = FALSE
@@ -298,18 +355,18 @@ canvasXpressOutput <- function(outputId, width = "100%", height = "400px") {
 #'
 #' @seealso \link[canvasXpress]{canvasXpressOutput}
 #' @seealso \link[canvasXpress]{cxShinyExample}
-#' 
+#'
 #' @section Destroy:
-#' When there exists a need to visually remove a plot from a Shiny 
+#' When there exists a need to visually remove a plot from a Shiny
 #' application when it is not being immediately replaced with a new plot use
-#' the destroy option as in:  
-#' 
+#' the destroy option as in:
+#'
 #' \code{renderCanvasXpress({canvasXpress(destroy = TRUE)})}
-#' 
+#'
 #' @export
 renderCanvasXpress <- function(expr, env = parent.frame(), quoted = FALSE) {
-    if (!quoted) { 
-        expr <- substitute(expr) 
+    if (!quoted) {
+        expr <- substitute(expr)
     } # force quoted
     htmlwidgets::shinyRenderWidget(expr, canvasXpressOutput, env, quoted = TRUE)
 }
