@@ -1,21 +1,21 @@
 assertDataCorrectness <- function(data, graphType, config) {
-    
+
     validGraphTypes <- c("Area", "AreaLine", "Bar", "BarLine", "Boxplot",
-                         "Circular", "Correlation", "Dotplot", "DotLine", 
-                         "Genome", "Heatmap", "Line", "Map", "Network", "Pie", 
-                         "ParallelCoordinates", "Sankey", "Scatter2D", 
-                         "Scatter3D", "ScatterBubble2D", "Stacked", 
-                         "StackedPercent", "StackedLine", "StackedPercentLine", 
+                         "Circular", "Correlation", "Dotplot", "DotLine",
+                         "Genome", "Heatmap", "Line", "Map", "Network", "Pie",
+                         "ParallelCoordinates", "Sankey", "Scatter2D",
+                         "Scatter3D", "ScatterBubble2D", "Stacked",
+                         "StackedPercent", "StackedLine", "StackedPercentLine",
                          "Tree", "Treemap", "TagCloud", "Venn")
     noDataNecessary  <- c("Map")
-    
+
     if (is.null(graphType)) stop("graphType cannot be NULL!")
 
     if (!(graphType %in% validGraphTypes)) {
         stop("graphType is invalid, must be one of <",
              paste(validGraphTypes, collapse = ", "), ">")
     }
-    
+
     # Implement data in URL
 	if (is.character(data)) {
 		if (httr::http_error(data)) {
@@ -25,7 +25,7 @@ assertDataCorrectness <- function(data, graphType, config) {
 	# for backwards compatibility we accept both data and vennData
 	else if (graphType == "Venn") {
         vdata <- data
-        
+
         if (is.null(vdata)) {
             if (!("vennData" %in% names(config))) {
                 stop("vennData cannot be NULL!")
@@ -34,11 +34,11 @@ assertDataCorrectness <- function(data, graphType, config) {
                 vdata <- config$vennData
             }
         }
-        
+
         if (!inherits(vdata, c("data.frame", "matrix", "list"))) {
             stop("vennData must be a data.frame, matrix, or named list")
         }
-        
+
         if (inherits(vdata, c("list")) & (length(vdata) > 1)) {
             stop("Venn diagrams do not support multiple datasets")
         }
@@ -46,7 +46,7 @@ assertDataCorrectness <- function(data, graphType, config) {
             stop("vennData cannot be NULL!")
         }
 
-        if (!("vennLegend" %in% names(config)) | 
+        if (!("vennLegend" %in% names(config)) |
             !("vennGroups" %in% names(config))) {
             stop("Venn diagrams must specify both the <vennLegend> and <vennGroups> parameters")
         }
@@ -62,26 +62,26 @@ assertDataCorrectness <- function(data, graphType, config) {
             edata <- data$edgeData
         }
         else {
-            if (!("nodeData" %in% names(config)) | 
+            if (!("nodeData" %in% names(config)) |
                 !("edgeData" %in% names(config))) {
                 stop("Network diagrams must specify both <nodeData> and <edgeData> as parameters or named data list items")
             }
             ndata <- config$nodeData
             edata <- config$edgeData
         }
-        
+
         if (is.null(ndata)) {
             stop("nodeData cannot be NULL!")
         }
-        
+
         if (is.null(edata)) {
             stop("edgeData cannot be NULL!")
         }
-        
+
         if (!inherits(ndata, c("data.frame", "matrix", "list"))) {
             stop("nodeData must be a data.frame or matrix or named list")
         }
-        
+
         if (!inherits(edata, c("data.frame", "matrix", "list"))) {
             stop("edgeData must be a data.frame or matrix or named list")
         }
@@ -94,32 +94,41 @@ assertDataCorrectness <- function(data, graphType, config) {
         if (!inherits(data, c("data.frame", "matrix", "list"))) {
             stop("data must be a data.frame, matrix, or named list")
         }
-        
+
         if (inherits(data, c("list"))) {
             if (length(data) < 1) {
                 stop("data specified as a list must contain at least one item")
             }
 
-            precalcBoxplot <- FALSE
-            
+            precalcBoxplot  <- FALSE
+            precalcBarchart <- FALSE
+
             if (length(data) > 1 ) {
                 if (is.null(names(data))) {
-                    stop("data specified as a list of multiple items must have named elements") 
+                    stop("data specified as a list of multiple items must have named elements")
                 }
                 else if (graphType == "Boxplot") {
                     req <- c("iqr1", "qtl1", "median", "qtl3", "iqr3")
                     precalcBoxplot <- (length(intersect(names(data), req)) == 5 ||
                                        length(intersect(rownames(data), req)) == 5)
-                    
+
                     if (!precalcBoxplot && !("y" %in% names(data))) {
                         stop("data specified as a list of multiple items must contain a <y> element")
                     }
                 }
+                else if (graphType == "Bar") {
+                    req <- c("mean", "stdev")
+                    precalcBarchart <- (length(intersect(names(data), req)) == 2 ||
+                                        length(intersect(rownames(data), req)) == 2)
+                    if (!precalcBarchart && !("y" %in% names(data))) {
+                        stop("data specified as a list of multiple items must contain a <y> element")
+                    }
+                }
                 else if (!("y" %in% names(data))) {
-                    stop("data specified as a list of multiple items must contain a <y> element") 
+                    stop("data specified as a list of multiple items must contain a <y> element")
                 }
             }
-            
+
             fail <- vector(mode = "character", length = 0)
 
             for (name in names(data)) {
@@ -127,13 +136,13 @@ assertDataCorrectness <- function(data, graphType, config) {
                     fail <- c(fail, name)
                 }
             }
-            if (!precalcBoxplot && length(fail) > 0) {
-                stop("data list elements <", paste(fail, collapse = ", "), 
+            if (!precalcBoxplot && !precalcBarchart && length(fail) > 0) {
+                stop("data list elements <", paste(fail, collapse = ", "),
                      "> are not data.frame or matrix elements")
             }
         }
     }
-    
+
 } #assertDataCorrectness
 
 
@@ -162,7 +171,7 @@ convertRowsToList <- function(x) {
         # From BBmisc
         seq_len(nrow(x))
     }
-    
+
     # From BBmisc
     res = lapply(seq_row(x), function(i) stats::setNames(x[i,], NULL))
     stats::setNames(res, rownames(x))
@@ -170,40 +179,40 @@ convertRowsToList <- function(x) {
 
 
 setup_y <- function(data) {
-    
+
     y <- NULL
-    
+
     if (inherits(data, "list")) {
         if (length(data) > 1) {
             y      <- lapply(data, as.matrix, dimnames = list())
             y$smps <- as.list(assignCanvasXpressColnames(data$y))
             y$vars <- as.list(assignCanvasXpressRownames(data$y))
-            
+
             #rename y to data for canvasXpress
-            y$data <- y$y  
+            y$data <- y$y
             y$y    <- NULL
         }
         else {
-            y <- list(vars = as.list(assignCanvasXpressRownames(data[[1]])), 
-                      smps = as.list(assignCanvasXpressColnames(data[[1]])), 
+            y <- list(vars = as.list(assignCanvasXpressRownames(data[[1]])),
+                      smps = as.list(assignCanvasXpressColnames(data[[1]])),
                       data = as.matrix(data[[1]], dimnames = list()))
         }
     }
     else {
-        y <- list(vars = as.list(assignCanvasXpressRownames(data)), 
-                  smps = as.list(assignCanvasXpressColnames(data)), 
+        y <- list(vars = as.list(assignCanvasXpressRownames(data)),
+                  smps = as.list(assignCanvasXpressColnames(data)),
                   data = as.matrix(data, dimnames = list()))
     }
-    
+
     y
 }
 
 setup_x <- function(y_smps, smpAnnot) {
     x <- NULL
-    
+
     if (!is.null(smpAnnot)) {
         test <- as.list(assignCanvasXpressRownames(smpAnnot))
-        
+
         if (!identical(test, y_smps)) {
             smpAnnot <- t(smpAnnot)
             test <- as.list(assignCanvasXpressRownames(smpAnnot))
@@ -215,28 +224,28 @@ setup_x <- function(y_smps, smpAnnot) {
 
         x <- lapply(convertRowsToList(t(smpAnnot)), function(d) if (length(d) > 1) d else list(d))
     }
-    
+
     x
 }
 
 setup_z <- function(y_vars, varAnnot) {
     z <- NULL
-    
+
     if (!is.null(varAnnot)) {
         test <- as.list(assignCanvasXpressRownames(varAnnot))
-        
+
         if (!identical(test, y_vars)) {
             varAnnot <- t(varAnnot)
             test <- as.list(assignCanvasXpressRownames(varAnnot))
         }
-        
+
         if (!identical(test, y_vars)) {
             stop("Row names in varAnnot are different from row names in data")
         }
 
         z <- lapply(convertRowsToList(t(varAnnot)), function(d) if (length(d) > 1) d else list(d))
     }
-    
+
     z
 }
 
