@@ -39,22 +39,27 @@ test_that("cXlayout9", {
 
 test_that("cXlayout10", {
     check_ui_test(cXlayout10())
-
-    warning("grouping results in different layout order")
 })
 
 test_that("cXlayout11", {
     check_ui_test(cXlayout11())
 
-    warning("grouping results in different layout order")
+    warning("The subcharts are in a different layout order compared to web example")
 })
 
 test_that("cXlayout12", {
     check_ui_test(cXlayout12())
+
+    warning("Colors for drug are different, two pieces are green, but one should be orange")
+    warning("The subcharts are in a different layout order compared to web example")
 })
 
 test_that("cXlayout13", {
     check_ui_test(cXlayout13())
+})
+
+test_that("cXlayout14", {
+    check_ui_test(cXlayout14())
 
     warning('middle section too small at default height - working as designed')
 })
