@@ -53,3 +53,6 @@ test_that("cXscatter2d13", {
     check_ui_test(cXscatter2d13())
 })
 
+test_that("cXscatter2d14", {
+    check_ui_test(cXscatter2d14())
+})
